@@ -1,6 +1,7 @@
 import time
 import traceback
 import yaml
+import json
 
 
 import os
@@ -15,8 +16,6 @@ from dataanalysis.caches.delegating import SelectivelyDelegatingCache
 import dqueue
 import imp
 
-
-
 try:
     import sentryclient
 except ImportError:
@@ -33,6 +32,7 @@ log=get_local_log("queue")
 class QueueCache(SelectivelyDelegatingCache):
     delegate_by_default=True
 
+
     def __init__(self,queue_directory="/tmp/queue"):
         super(QueueCache, self).__init__()
         self.queue_directory=queue_directory
@@ -47,6 +47,7 @@ class QueueCache(SelectivelyDelegatingCache):
         )
 
         r = None
+        problems = []
         for i in range(20):
             try:
                 r=self.queue.put(
@@ -57,14 +58,16 @@ class QueueCache(SelectivelyDelegatingCache):
                     ),
                 )
                 if getattr(r, 'status_code', 200) != 200:
+                    problems.append(f"problematic response from put task {r}")
                     raise Exception(f"problematic response from put task {r}")
                 break
             except Exception as e:
                 log("problem putting task:", e)
+                problems.append(f"problem putting task {e}, attempt {i}")
                 time.sleep(2)
 
         if r is None:
-            raise Exception(f"unable to put task in queue: {task_data}")
+            raise Exception(f"unable to put task in queue, problems {problems} task_data: {task_data}")
         
         log(self,"\033[31mdelegated",obj,"\033[0m with state", r['state'], level="top")
 
@@ -102,17 +105,25 @@ class QueueCacheWorker(object):
     def __repr__(self):
         return "[%s: %i]"%(self.__class__.__name__,id(self))
 
-    def __init__(self,queue_directory="default"):
+    def __init__(self,queue_directory="default", worker_id=None):
         self.queue_directory = queue_directory
 
-        self.load_queue()
+        self.load_queue(worker_id)
         print("initialized dqueue:", self.queue)
 
-    def load_queue(self):
-        self.queue = dqueue.from_uri(self.queue_directory)
+    json_log_file = None
+
+    def log_json(self, j):
+        self.queue.log_task(json.dumps(j))
+        if self.json_log_file:
+            self.json_log_file.write(json.dumps(j)+"\n")
+            self.json_log_file.flush()
+
+    def load_queue(self, worker_id=None):
+        self.queue = dqueue.from_uri(self.queue_directory, worker_id)
 
 
-    def run_task(self,task):
+    def run_task(self, task):
         task_data=task.task_data
         log("emerging from object_identity",task_data['object_identity'])
         object_identity=da.DataAnalysisIdentity.from_dict(task_data['object_identity'])
@@ -120,18 +131,36 @@ class QueueCacheWorker(object):
 
         imp.reload(dataanalysis.graphtools)
         log("fresh factory knows",da.AnalysisFactory.cache)
+        
+        t_start = time.time()
+        self.log_json(dict(
+                    origin="oda-worker",
+                    action="worker_taking_task",
+                    object_factory_name=object_identity.factory_name,
+                    worker_id=self.queue.worker_id,
+                ))
 
         log(object_identity)
         A=emerge.emerge_from_identity(object_identity)
         A._da_delegation_allowed=False
 
         dataanalysis.callback.Callback.set_callback_accepted_classes([da.byname(object_identity.factory_name).__class__])
+        
+        t_start_get = time.time()
+        self.queue.log_task(json.dumps(dict(
+                    origin="oda-worker",
+                    action="worker_emerged_task",
+                    object_factory_name=object_identity.factory_name,
+                    worker_id=self.queue.worker_id,
+                )))
+
 
         for url in task.submission_info.get('callbacks', []):
             log("setting object callback",A,url)
             A.set_callback(url)
 
         log("emerged object:",A)
+        
 
         request_root_node=getattr(A, 'request_root_node', False)
         if request_root_node:
@@ -159,9 +188,26 @@ class QueueCacheWorker(object):
             if client is not None:
                 client.captureException()
 
+            self.log_json(dict(
+                            origin="oda-worker",
+                            action="run_task_exception",
+                            object_factory_name=A.factory_name,
+                            object_fullname=str(A),
+                            tspent_s=time.time()-t_start,
+                            tspent_get_s=time.time()-t_start_get,
+                         ))
+
             raise
         else:
             A.process_hooks("top",A,message="task complete",state=final_state, task_comment="completed with success")
+            self.log_json(dict(
+                            origin="oda-worker",
+                            action="run_task_complete",
+                            object_factory_name=object_identity.factory_name,
+                            object_fullname=str(A),
+                            tspent_s=time.time()-t_start,
+                            tspent_get_s=time.time()-t_start_get,
+                         ))
             return result
 
 
@@ -300,6 +346,8 @@ def main():
     parser.add_argument('-W', dest='watch_closely', type=int, help='...', default=0)
     parser.add_argument('-d', dest='delay', type=int, help='...', default=10)
     parser.add_argument('-k', dest='worker_knowledge_yaml', type=str, help='...', default=None)
+    parser.add_argument('-n', dest='worker_id', type=str, help='...', default=None)
+    parser.add_argument('--json-log-file', dest='json_log_file', type=str, help='...', default=None)
 
     args=parser.parse_args()
 
@@ -307,9 +355,11 @@ def main():
         dataanalysis.printhook.global_permissive_output=True
         da.debug_output()
 
+    qcworker = QueueCacheWorker(args.queue, args.worker_id)
 
+    if args.json_log_file:
+        qcworker.json_log_file = open(args.json_log_file, "at")
 
-    qcworker = QueueCacheWorker(args.queue)
 
     if args.worker_knowledge_yaml is not None:
         qcworker.set_worker_knowledge(yaml.load(open(args.worker_knowledge_yaml), Loader=yaml.FullLoader))
