@@ -41,6 +41,16 @@ log=get_local_log(__name__)
 
 from dataanalysis.callback import CallbackHook
 
+def repr_short(d):
+    lim = 100
+
+    r = repr(d)
+
+    if len(r)<lim*2:
+        return r
+
+    return r[:lim] + " ... " + r[-lim:]
+
 dda_hooks=[CallbackHook(),log_hook]
 
 Cache = cache_core.CacheNoIndex()
@@ -673,8 +683,8 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
 
 
     def serialize(self,embed_datafiles=True,verify_jsonifiable=True,include_class_attributes=True,deep_export=True):
-        log("serialize",self,"as",embed_datafiles,verify_jsonifiable,include_class_attributes)
-        return self.get_factory_name(),self.export_data(embed_datafiles,verify_jsonifiable,include_class_attributes,deep_export)
+        log("serialize", self, "as", embed_datafiles, verify_jsonifiable, include_class_attributes)
+        return self.get_factory_name(), self.export_data(embed_datafiles, verify_jsonifiable, include_class_attributes, deep_export)
 
     # the difference between signature and version is that version can be avoided in definition and substituted later
     # it can be done differently
@@ -1304,8 +1314,9 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
         log('object assumptions:',self.assumptions,'{log:top}')
 
         if 'callback_url' in extra:
-            log("setting callback from process:",extra['callback_url'])
+            log(self, "setting callback from process:",extra['callback_url'])
             self.set_callback(extra['callback_url'])
+            log(self, "now callbacks:", self.callbacks)
 
         restore_config=self.process_restore_config(restore_config)
         restore_rules=self.process_restore_rules(restore_rules,extra)
@@ -1552,7 +1563,7 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
         if self._da_callbacks is None:
             return []
         else:
-            log("callbacks",self._da_callbacks)
+            log("requested callbacks property", self._da_callbacks, level="callback")
             return self._da_callbacks
 
     def prepare_restore_config(self,restore_config):
@@ -1659,7 +1670,7 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
                     inputs.append(l)
 
             if delegated != []:
-                log("delegated:",len(delegated),delegated,level="top")
+                log("delegated:", len(delegated), repr_short(delegated),level="top")
                 log("still implemented:", len(inputhashes),inputs)
 
                 raise AnalysisDelegatedException.from_list(delegated)
@@ -1695,7 +1706,7 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
                     nitems.append(ni)
 
                 if delegated!=[]:
-                    log("delegated:", len(delegated), delegated)
+                    log("delegated:", len(delegated), (lambda x:x[:100]+" ... "+x[-100:])(repr(delegated)))
                     raise AnalysisDelegatedException.from_list(delegated)
                 else:
                     log("no delegated analysis found")
@@ -1729,7 +1740,12 @@ class DataAnalysis(with_metaclass(decorate_all_methods, object)):
             log("item:",item._da_locally_complete)
         except Exception as e:
             raise Exception(str(item)+" has no locally complete!")
-        input_hash,newitem=item.process(restore_rules=rr,restore_config=restore_config,requested_by=requested_by, callback_url=self.callbacks) # recursively for all inputs process input
+        input_hash,newitem = item.process(
+                                restore_rules=rr,
+                                restore_config=restore_config,
+                                requested_by=requested_by, 
+                                callback_url=self.callbacks
+                            ) # recursively for all inputs process input
         log("process_input finishing at the end",input_hash,newitem)
 
         return input_hash,newitem # return path to the item (hash) and the item
